@@ -53,15 +53,12 @@ public:
 
     static int              autoHideSystemTray();
     static void             setAutoHideSystemTray(int timeout);
-    static bool             autoStartChangedByUser()         { return mAutoStartChangedByUser; }
-    static void             setAutoStartChangedByUser(bool c){ mAutoStartChangedByUser = c; }
 
     // Access to settings
     static QString          previousVersion()                { return mPreviousVersion; }
     static Backend          previousBackend()                { return mPreviousBackend; }
-    static void             setAskAutoStart(bool yes);
-    static bool             noAutoStart()                    { return self()->base_NoAutoStart(); }
-    static void             setNoAutoStart(bool yes);
+    static RunMode          runMode()                        { return self()->base_RunMode(); }
+    static void             setRunMode(RunMode);
     static bool             modalMessages();
     static void             setModalMessages(bool yes);
     static int              messageButtonDelay();
@@ -137,10 +134,9 @@ public:
     static void             setDefaultSoundVolume(float v)   { self()->setBase_DefaultSoundVolume(v < 0 ? -1 : static_cast<int>(v * 100)); }
 
     // Config file entry names for notification messages
-    static const QLatin1String QUIT_WARN;
-    static const QLatin1String ASK_AUTO_START;
-    static const QLatin1String CONFIRM_ALARM_DELETION;
-    static const QLatin1String EMAIL_QUEUED_NOTIFY;
+    static const QLatin1StringView QUIT_WARN;
+    static const QLatin1StringView CONFIRM_ALARM_DELETION;
+    static const QLatin1StringView EMAIL_QUEUED_NOTIFY;
 
     bool                    useDefaults(bool def) override   { mUsingDefaults = def;  return PreferencesBase::useDefaults(def); }
 
@@ -169,9 +165,6 @@ private:
 
     // All the following members are accessed by the Preferences dialog classes
     static int              mMessageButtonDelay;  // 0 = scatter; -1 = no delay, no scatter; >0 = delay, no scatter
-
-    // Change tracking
-    static bool             mAutoStartChangedByUser; // AutoStart has been changed by the user
 };
 
 // vim: et sw=4:
